@@ -98,7 +98,7 @@ class TgUpload:
         self.start_workers()
         self.start_producers()
         self.q.join()
-        self.clean_up()
+        #self.clean_up()
         logging.info('All work completed')
 
 
